@@ -7,13 +7,13 @@
 
 abline.rv <- function (a = NULL, b = NULL, h = NULL, v = NULL, ...) { ## NEW
   if (! anyisrv(a, b, h, v)) {
-    return(graphics:::abline(a=a, b=b, h=h, v=v, ...))
+    return(abline(a=a, b=b, h=h, v=v, ...))
   }
   line.sample <- rvpar("line.sample")
   if (!is.numeric(line.sample)) {
     stop("rvpar('line.sample') is not a number")
   }
-  args <- list(FUN=graphics:::abline, a=a, b=b, h=h, v=v)
+  args <- list(FUN=abline, a=a, b=b, h=h, v=v)
   nulls <- sapply(args, is.null)
   nullArgs <- names(nulls)[nulls]
   MoreArgs <- list(...)
