@@ -1,7 +1,7 @@
 
 
 rvexp <- function (n=1, rate=1) {
-  rvvapply(stats:::rexp, n.=n, rate=rate)
+  rvvapply(rexp, n.=n, rate=rate)
 }
 
 
