@@ -7,6 +7,6 @@
 rvhyper <- function(nn=1, m, n, k) {
   warning("NOT YET READY")
   attr(nn, "n.name") <- "nn"
-  rvvapply(stats:::rhyper, n.=nn, m=m, n=n, k=k)
+  rvvapply(rhyper, n.=nn, m=m, n=n, k=k)
 }
 
