@@ -5,6 +5,6 @@ rvngamma <- function (n=1, shape, rate = 1, scale = 1/rate) {
     stop("shape parameter must be nonnegative")
   }
   shape <- (1/3 + shape)
-  rvvapply(stats:::rgamma, n.=n, shape=shape, scale=scale)
+  rvvapply(rgamma, n.=n, shape=shape, scale=scale)
 }
 
